| list_estimators | R Documentation |
idiographic uses a small registry to give estimators and workflows one
stable dispatch interface. Package methods are registered lazily, so the
registry does not depend on source-file load order. Third-party methods can
register either a function or the name of a function available in the
package namespace or calling environment.
list_estimators(kind = NULL)
kind |
Optional character vector selecting |
list_estimators() returns one row per registration.
list_estimators()
list_estimators("workflow")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.